@@ -163,10 +163,7 @@ class InternalBuilderBackend():
     @staticmethod
     def _get_basic_packages():
         """Return a list of basic packages for all king of images."""
-        # initramfs-tools is a dependency for the kernel-image package.
-        # However, when kernel is not installed as in case of Raspberry Pi
-        # image, explicit dependency is needed.
-        return ['initramfs-tools', 'firmware-ath9k-htc']
+        return ['firmware-ath9k-htc']
 
     def _get_kernel_packages(self):
         """Return package needed for kernel."""
@@ -226,6 +223,7 @@ class InternalBuilderBackend():
 
     def _install_freedombox_packages(self):
         """Install custom .deb packages."""
+        custom_freedombox = None
         custom_plinth = None
         custom_setup = None
         for package in (self.builder.arguments.custom_package or []):
@@ -233,6 +231,11 @@ class InternalBuilderBackend():
                 custom_plinth = package
             elif 'freedombox-setup_' in package:
                 custom_setup = package
+            elif 'freedombox_' in package:
+                custom_freedombox = package
+
+        if custom_freedombox:
+            library.install_custom_package(self.state, custom_freedombox)
 
         if custom_plinth:
             library.install_custom_package(self.state, custom_plinth)
